TypeConverter (py4j-java 0.10.0 API)
Date: 2016-04-18

py4j.reflection

## Class TypeConverter

- java.lang.Object
- - py4j.reflection.TypeConverter

-     public class TypeConverter
      extends java.lang.Object

  A TypeConverter converts a Python type into a Java Type. For example, a Python String might be converted to a Java character (e.g., when calling a method that only accepts characters).

- - ### Field Summary

    Fields
    Modifier and Type | Field and Description
    --- | ---
    `static TypeConverter` | `BYTE_CONVERTER`
    `static TypeConverter` | `CHAR_CONVERTER`
    `static int` | `DOUBLE_TO_FLOAT`
    `static TypeConverter` | `FLOAT_CONVERTER`
    `static int` | `INT_TO_BYTE`
    `static int` | `INT_TO_SHORT`
    `static TypeConverter` | `LONG_CONVERTER`
    `static int` | `NO_CONVERSION`
    `static TypeConverter` | `NO_CONVERTER`
    `static int` | `NUM_TO_LONG`
    `static TypeConverter` | `SHORT_CONVERTER`
    `static int` | `STRING_TO_CHAR`

  - ### Constructor Summary

    Constructors
    Constructor and Description
    `TypeConverter()`
    `TypeConverter(int conversion)`

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `java.lang.Object` | `convert(java.lang.Object obj)`
    `int` | `getConversion()`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Field Detail

    - #### NO_CONVERSION

          public static final int NO_CONVERSION

      See Also:
        Constant Field Values

    - #### DOUBLE_TO_FLOAT

          public static final int DOUBLE_TO_FLOAT

      See Also:
        Constant Field Values

    - #### INT_TO_SHORT

          public static final int INT_TO_SHORT

      See Also:
        Constant Field Values

    - #### INT_TO_BYTE

          public static final int INT_TO_BYTE

      See Also:
        Constant Field Values

    - #### STRING_TO_CHAR

          public static final int STRING_TO_CHAR

      See Also:
        Constant Field Values

    - #### NUM_TO_LONG

          public static final int NUM_TO_LONG

      See Also:
        Constant Field Values

    - #### NO_CONVERTER

          public static final TypeConverter NO_CONVERTER

    - #### FLOAT_CONVERTER

          public static final TypeConverter FLOAT_CONVERTER

    - #### SHORT_CONVERTER

          public static final TypeConverter SHORT_CONVERTER

    - #### BYTE_CONVERTER

          public static final TypeConverter BYTE_CONVERTER

    - #### CHAR_CONVERTER

          public static final TypeConverter CHAR_CONVERTER

    - #### LONG_CONVERTER

          public static final TypeConverter LONG_CONVERTER

  - ### Constructor Detail

    - #### TypeConverter

          public TypeConverter()

    - #### TypeConverter

          public TypeConverter(int conversion)

  - ### Method Detail

    - #### convert

          public java.lang.Object convert(java.lang.Object obj)

    - #### getConversion

          public int getConversion()